[pkg-fso-commits] [SCM] FSO frameworkd Debian packaging branch, debian, updated. upstream/0.9.5.5-717-g0f98819

Sebastian Krzyszkowiak seba.dos1 at gmail.com
Sat Aug 6 08:17:57 UTC 2011


The following commit has been merged in the debian branch:
commit b711d1831d1dcbc429e7756d9a75d076a7adf9e1
Author: Sebastian Krzyszkowiak <seba.dos1 at gmail.com>
Date:   Thu Aug 20 13:43:17 2009 +0200

    opimd: add Todos domain

diff --git a/framework/subsystems/opimd/opimd.py b/framework/subsystems/opimd/opimd.py
index 696e2e9..3e66b03 100644
--- a/framework/subsystems/opimd/opimd.py
+++ b/framework/subsystems/opimd/opimd.py
@@ -47,6 +47,7 @@ import pimd_messages
 import pimd_calls
 import pimd_dates
 import pimd_notes
+import pimd_todos
 # Same thing for the backend modules
 import pimb_sim_contacts_fso
 import pimb_sim_messages_fso
diff --git a/framework/subsystems/opimd/pimd_notes.py b/framework/subsystems/opimd/pimd_todos.py
similarity index 90%
copy from framework/subsystems/opimd/pimd_notes.py
copy to framework/subsystems/opimd/pimd_todos.py
index 7e46cff..53fba09 100644
--- a/framework/subsystems/opimd/pimd_notes.py
+++ b/framework/subsystems/opimd/pimd_todos.py
@@ -9,9 +9,9 @@ Open PIM Daemon
 (C) 2009 Sebastian Krzyszkowiak <seba.dos1 at gmail.com>
 GPLv2 or later
 
-Notes Domain Plugin
+Todos Domain Plugin
 
-Establishes the 'Notes' PIM domain and handles all related requests
+Establishes the 'Todos' PIM domain and handles all related requests
 """
 
 from dbus.service import FallbackObject as DBusFBObject
@@ -38,22 +38,22 @@ from pimd_generic import GenericEntry, GenericDomain
 
 #----------------------------------------------------------------------------#
 
-_DOMAIN_NAME = "Notes"
+_DOMAIN_NAME = "Todos"
 
 _DBUS_PATH_NOTES = DBUS_PATH_BASE_FSO + '/' + _DOMAIN_NAME
 _DIN_NOTES_BASE = DIN_BASE_FSO
 
 _DBUS_PATH_QUERIES = _DBUS_PATH_NOTES + '/Queries'
 
-_DIN_NOTES = _DIN_NOTES_BASE + '.' + 'Notes'
-_DIN_ENTRY = _DIN_NOTES_BASE + '.' + 'Note'
-_DIN_QUERY = _DIN_NOTES_BASE + '.' + 'NoteQuery'
+_DIN_NOTES = _DIN_NOTES_BASE + '.' + 'Todos'
+_DIN_ENTRY = _DIN_NOTES_BASE + '.' + 'Todo'
+_DIN_QUERY = _DIN_NOTES_BASE + '.' + 'TodoQuery'
 
 
 #----------------------------------------------------------------------------#
-class Note(GenericEntry):
+class Todo(GenericEntry):
 #----------------------------------------------------------------------------#
     """Represents one single note with all the data fields it consists of.
 
     _fields[n] = [field_name, field_value, value_used_for_comparison, source]
 
@@ -76,7 +76,7 @@ class QueryManager(DBusFBObject):
     _entries = None
     _next_query_id = None
 
     # Note: _queries must be a dict so we can remove queries without messing up query IDs
 
     def __init__(self, entries):
         """Creates a new QueryManager instance
@@ -115,7 +115,7 @@ class QueryManager(DBusFBObject):
     def check_new_entry(self, entry_id):
         """Checks whether a newly added entry matches one or more queries so they can signal clients
 
-        @param entry_id Note ID of the note that was added"""
+        @param entry_id Todo ID of the todo that was added"""
 
         for (query_id, query_handler) in self._queries.items():
             if query_handler.check_new_entry(entry_id):
@@ -131,10 +131,10 @@ class QueryManager(DBusFBObject):
             raise InvalidQueryID( "Existing query IDs: %s" % self._queries.keys() )
 
     def EntryAdded(self, path, rel_path=None):
-        self.NoteAdded(path, rel_path=rel_path)
+        self.TodoAdded(path, rel_path=rel_path)
 
     @dbus_signal(_DIN_QUERY, "s", rel_path_keyword="rel_path")
-    def NoteAdded(self, path, rel_path=None):
+    def TodoAdded(self, path, rel_path=None):
         pass
 
     @dbus_method(_DIN_QUERY, "", "i", rel_path_keyword="rel_path")
@@ -162,7 +162,7 @@ class QueryManager(DBusFBObject):
 
 
     @dbus_method(_DIN_QUERY, "", "s", rel_path_keyword="rel_path", sender_keyword="sender")
-    def GetNotePath(self, rel_path, sender):
+    def GetTodoPath(self, rel_path, sender):
         num_id = int(rel_path[1:])
         self.check_query_id_ok( num_id )
 
@@ -196,7 +196,7 @@ class QueryManager(DBusFBObject):
         self._queries.__delitem__(num_id)
 
 #----------------------------------------------------------------------------#
-class NoteDomain(Domain, GenericDomain):
+class TodoDomain(Domain, GenericDomain):
 #----------------------------------------------------------------------------#
     name = _DOMAIN_NAME
 
@@ -207,9 +207,9 @@ class NoteDomain(Domain, GenericDomain):
     Entry = None
 
     def __init__(self):
         """Creates a new NoteDomain instance"""
 
-        self.Entry = Note
+        self.Entry = Todo
 
         self._backends = {}
         self._entries = []
@@ -229,10 +229,10 @@ class NoteDomain(Domain, GenericDomain):
     #---------------------------------------------------------------------#
 
     def NewEntry(self, path):
-        self.NewNote(path)
+        self.NewTodo(path)
 
     @dbus_signal(_DIN_NOTES, "s")
-    def NewNote(self, path):
+    def NewTodo(self, path):
         pass
 
     @dbus_method(_DIN_NOTES, "a{sv}", "s")
@@ -290,11 +290,11 @@ class NoteDomain(Domain, GenericDomain):
         return self.get_multiple_fields(num_id, field_list)
 
     @dbus_signal(_DIN_ENTRY, "", rel_path_keyword="rel_path")
-    def NoteDeleted(self, rel_path=None):
+    def TodoDeleted(self, rel_path=None):
         pass
 
     def EntryDeleted(self, rel_path=None):
-        self.NoteDeleted(rel_path=rel_path)
+        self.TodoDeleted(rel_path=rel_path)
 
     @dbus_method(_DIN_ENTRY, "", "", rel_path_keyword="rel_path")
     def Delete(self, rel_path):
@@ -303,10 +303,10 @@ class NoteDomain(Domain, GenericDomain):
         self.delete(num_id)
 
     def EntryUpdated(self, data, rel_path=None):
-        self.NoteUpdated(data, rel_path=rel_path)
+        self.TodoUpdated(data, rel_path=rel_path)
 
     @dbus_signal(_DIN_ENTRY, "a{sv}", rel_path_keyword="rel_path")
-    def NoteUpdated(self, data, rel_path=None):
+    def TodoUpdated(self, data, rel_path=None):
         pass
 
     @dbus_method(_DIN_ENTRY, "a{sv}", "", rel_path_keyword="rel_path")
@@ -38,22 +38,22 @@ from pimd_generic import GenericEntry, GenericDomain
 #----------------------------------------------------------------------------#
-    """Represents one single note with all the data fields it consists of.
+    """Represents one single todo with all the data fields it consists of.
 
     _fields[n] = [field_name, field_value, value_used_for_comparison, source]
@@ -76,7 +76,7 @@ class QueryManager(DBusFBObject):
     _next_query_id = None
 
-    # Note: _queries must be a dict so we can remove queries without messing up query IDs
+    # Todo: _queries must be a dict so we can remove queries without messing up query IDs
 
     def __init__(self, entries):
@@ -207,9 +207,9 @@ class NoteDomain(Domain, GenericDomain):
 
     def __init__(self):
-        """Creates a new NoteDomain instance"""
+        """Creates a new TodoDomain instance"""
 

-- 
FSO frameworkd Debian packaging



More information about the pkg-fso-commits mailing list